<?php


function readContainerConfig() {
  try {
    $testString = 'This is a test file for LakeDrops GitLab CI';
    $filename = '/tmp/' . random_int(100,999) . '.test';
    file_put_contents($filename, $testString);
    $output = [];
    exec('docker ps -q', $output);
    $id = NULL;
    foreach ($output as $id) {
      $output = [];
      exec('docker exec ' . $id . ' cat ' . $filename . ' 2>&1', $output);
      if (reset($output) === $testString) {
        // Found the container.
        break;
      }
    }
    unlink($filename);
    if ($id === NULL) {
      return [];
    }
    $output = [];
    exec('docker container inspect ' . $id, $output);
    return json_decode(implode('', $output), TRUE, 512, JSON_THROW_ON_ERROR)[0];
  }
  catch (\Exception $ex) {
    // Ignore.
  }
  return [];
}

function getDockerMountSource($args) {
  $currentDir = getcwd();
  $suffix = (empty($args[2])) ? '' : '/' . $args[2];
  $destDir = (empty($args[1])) ? $currentDir : $args[1];

  $container = readContainerConfig();
  foreach ($container['Mounts'] as $mount) {
    if (strpos($currentDir, $mount['Destination']) === 0) {
      return $mount['Source'] . $suffix . ':' . (empty($args[1]) ? $mount['Destination'] : $destDir) . $suffix;
    }
  }
  return $currentDir . $suffix . ':' . $destDir . $suffix;
}

function getAllDockerMountSources() {
  $volumes = [];
  $container = readContainerConfig();
  foreach ($container['Mounts'] as $mount) {
    $volumes[] = '-v ' . $mount['Source'] . ':' . $mount['Destination'];
  }
  return implode(' ', $volumes);
}

function getHostSource() {
  $currentDir = getcwd();
  $container = readContainerConfig();
  foreach ($container['Mounts'] as $mount) {
    if (strpos($currentDir, $mount['Destination']) === 0) {
      return $mount['Source'] . str_replace($mount['Destination'], '', $currentDir);
    }
  }
  return 'unknown';
}

if ($argc === 2 && $argv[1] === '--none') {
  print(getHostSource());
}
elseif ($argc === 1 || $argv[1] !== '--all') {
  print(getDockerMountSource($argv));
}
else {
  print(getAllDockerMountSources());
}
